--Parallel Statistics Update

 select 
 schemas.name as table_schema,
 tbls.name as table_name, 
 i.name as index_name, 
 i.id as table_id, 
 i.indid as index_id,
 i.groupid,
 i.rowmodctr as modifiedRows,
 (select max(rowcnt) from sysindexes i2 where i.id = i2.id and i2.indid < 2) as rowcnt,
 stats_date( i.id, i.indid ) as lastStatsUpdate,
 'False' as Processed
 into ##updateStatsQueue
 from sysindexes i
 inner join sysobjects tbls on i.id = tbls.id
 inner join sysusers schemas on tbls.uid = schemas.uid
 inner join information_schema.tables tl 
 on tbls.name = tl.table_name 
 and schemas.name = tl.table_schema
 and tl.table_type='BASE TABLE'
 where 0 < i.indid and i.indid < 255
 and table_schema <> 'sys'
 and i.rowmodctr <> 0
 and (select max(rowcnt) from sysindexes i2 where i.id = i2.id and i2.indid < 2) > 0

 select max(rowcnt) from sysindexes i2 where i.id = i2.id and i2.indid < 2 

 declare @starttime datetime;
 set @starttime = getdate();
 -- Number of minutes to continue updating stats
 -- Routine will complete its current operation and exit
 -- if more than this timespan has elapsed:
 declare @maxDur decimal (5,2);
 set @maxdur = 480;
 print 'Updating statistics in ' + DB_NAME();
 print '';
 set nocount on;
 -- Make the queue of indexes to update:
 if object_id('tempdb..##updateStatsQueue') is not null drop table ##updateStatsQueue;
 select 
 schemas.name as table_schema,
 tbls.name as table_name, 
 i.name as index_name, 
 i.id as table_id, 
 i.indid as index_id,
 i.groupid,
 i.rowmodctr as modifiedRows,
 (select max(rowcnt) from sysindexes i2 where i.id = i2.id and i2.indid < 2) as rowcnt,
 stats_date( i.id, i.indid ) as lastStatsUpdate,
 'False' as Processed
 into ##updateStatsQueue
 from sysindexes i
 inner join sysobjects tbls on i.id = tbls.id
 inner join sysusers schemas on tbls.uid = schemas.uid
 inner join information_schema.tables tl 
 on tbls.name = tl.table_name 
 and schemas.name = tl.table_schema
 and tl.table_type='BASE TABLE'
 where 0 < i.indid and i.indid < 255
 and table_schema <> 'sys'
 and i.rowmodctr <> 0
 and (select max(rowcnt) from sysindexes i2 where i.id = i2.id and i2.indid < 2) > 0;
 
 -- Start worker jobs to process the queue
 print 'Starting worker jobs';
 -- Change the job names below as needed for implementation:
 exec msdb..sp_start_job @job_name = 'Update Stats Worker 1';
 exec msdb..sp_start_job @job_name = 'Update Stats Worker 2';
 exec msdb..sp_start_job @job_name = 'Update Stats Worker 3';
 exec msdb..sp_start_job @job_name = 'Update Stats Worker 4';
 -- Monitor the queue; remove its temp table and exit once the entire table 
 -- has been processed or the max duration has elapsed:
 while ( datediff( minute, @starttime, getdate() ) < @maxdur 
 and exists( select 1 from ##updateStatsQueue where processed = 'False' ) )
 begin
 -- Pause while worker jobs update stats
 print 'Working ' + cast( getdate() as varchar(50) );
 waitfor delay '000:02:00';
 end
 drop table ##updateStatsQueue;
 print '';
 print 'Statistics update stopped/ended ' + cast( getdate() as varchar(50) );

 -- Process statistics objects from queue ##updateStatsQueue
 -- until it has been completely processed or no longer exists
 print 'Updating statistics in ' + DB_NAME() 
 print ''
 declare @curtable sysname;
 declare @curschema sysname;
 declare @curindex sysname;
 declare @curmodrows int;
 declare @currows bigint;
 declare @sql varchar(2000);
 -- Loop until we run out of stats objects or the queue is dropped
 while ( object_id('tempdb..##updateStatsQueue') is not null )
 begin
 -- Get the top stats object to work on, and remove its entry from the queue
 
 update ##updateStatsQueue 
 set @curschema = table_schema = q.table_schema, 
 @curtable = table_name = q.table_name,
 @curindex = index_name = q.index_name,
 @currows = rowcnt = q.rowcnt,
 @curmodrows = modifiedRows = q.modifiedRows,
 processed = 'True'
 from ##updateStatsQueue q
 inner join ( select top 1 * 
 from ##updateStatsQueue q3
 where processed = 'False'
 
 -- Note: You may wish to add criteria or change the order clause here to 
 -- tune the ordering of statistics updates for your specific server:
 -- For example: "and groupid = (x)" or "and table_name like '[a-g]%'"
 -- The ordering given is from tables with a large percentage modified rows
 -- to tables with a small percentage modified rows (preventing divide by zero)
 order by abs(modifiedrows)/( cast( rowcnt as decimal ) + 0.01 ) desc, lastStatsUpdate
 ) q2
 on q.table_schema = q2.table_schema
 and q.table_name = q2.table_name
 and q.index_name = q2.index_name;
 -- If the update statement found no matching rows, then our work is done; exit:
 if @@ROWCOUNT = 0 break;
 else 
 begin
 print cast( getdate() as varchar(100) );
 print 'Updating stats for ' 
 + '[' + @curschema + '].[' + @curtable + '].[' + @curindex + ']'
 + '(' + cast( @curmodrows as varchar(1000) ) + ' modifications against ' 
 + cast( @currows as varchar(1000) ) + ' rows.)';
 set @sql = 'update statistics ' 
 + '[' + @curschema + '].[' + @curtable + '] [' + @curindex + ']'
 + ' with fullscan '
 exec( @sql );
 end
 end
 print ''
 Print 'Statistics update stopped/ended ' + cast( getdate() as varchar(50) );